/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel;

/**
 * An exception thrown if the expression contains illegal syntax.
 *
 * @version 
 */
public class ExpressionIllegalSyntaxException extends RuntimeCamelException {
    private static final long serialVersionUID = 6545652894842621836L;

    private final String expression;

    public ExpressionIllegalSyntaxException(String expression) {
        this(expression, null);
    }

    public ExpressionIllegalSyntaxException(String expression, Throwable cause) {
        super("Illegal syntax: " + expression, cause);
        this.expression = expression;
    }

    public String getExpression() {
        return expression;
    }

}
